export declare type Tlogging = 'fatal' | 'error' | 'warn' | 'important' | 'info' | 'success' | 'verbose';
declare class OurLogging {
    #private;
    /**
     * If enabled will sort all new logs in directory by MONTH_YYYY with names DD.log
     * eg October_2022/31.log
     */
    setSeparateLogsByDate(value: boolean): void;
    /**
     * logs by level decrease: 'fatal' | 'error' | 'warn' | 'important' | 'info' | 'success' | 'verbose'
     * @param level log that you want to see in console
     * @example logging.setLogLevel('important')
     * // After that only fatal, error, warn, important logs will shown
     */
    setLogLevel(newLevel: Tlogging): void;
    /**
     * @param name full path to file with logs
     */
    setLogfileName(name: string): void;
    /**
     * Use only for most important staff like db connection
     * Will show stack in console
     * @param text will be seen first by user
     * @param stackTrace will be showed after text and logged into file
     * @example throw logging.fatal('DB connection error', err.stack)
     * @returns Error object with text
     */
    fatal(text: string, stackTrace?: string): Error;
    /**
     * Important but not cicritical errors
     * @param text
     * @returns Error object with error text
     */
    error(...texts: any[]): Error | undefined;
    /**
     * Some suspicious things, noticeable in console
     * EG on server start database logging turn off
     * @param text
     */
    warn(...texts: any[]): void;
    /**
     * Some important things, noticeable in console
     * @param text
     */
    important(...texts: any[]): void;
    /**
     * Not noticeable in console
     * @param text
     */
    info(...texts: any[]): void;
    /**
     * Gray colored log, use it for less important things than info.
     * You can turn off verbose logs (not show it in console, browser, file)
     * by setting log level to success: logging.setLogLevel('success')
     * @param text
     */
    verbose(...texts: any[]): void;
    /**
     * Noticeable in console, green color
     * @param text
     */
    success(...texts: any[]): void;
}
declare const logging: OurLogging;
export default logging;
