"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDateTime = exports.logTextToFile = exports.normalizeTexts = exports.coloredConsoleLog = exports.getColoredText = void 0;
const path_1 = require("path");
const fs_1 = __importDefault(require("fs"));
const colors_js_1 = require("./colors.js");
function getColoredText(text, color = 'black', ...notColoredTexts) {
    // const colors: { [key in Tcolor]: ChalkInstance } = {
    const coloredText = colors_js_1.colors[color](text) + notColoredTexts;
    return coloredText;
}
exports.getColoredText = getColoredText;
function coloredConsoleLog(text, color = 'black', ...notColoredTexts) {
    const coloredText = getColoredText(text, color);
    console.log(coloredText, ...notColoredTexts);
}
exports.coloredConsoleLog = coloredConsoleLog;
const normalizeTexts = (...texts) => texts.map(text => {
    if (typeof text === 'object')
        return JSON.stringify(text);
    return text;
});
exports.normalizeTexts = normalizeTexts;
function logTextToFile(text, fileName, separeteLogsByDate) {
    if (!fileName)
        return;
    if (separeteLogsByDate) {
        var months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
        const date = new Date();
        const year = date.getFullYear();
        const monthName = months[date.getMonth()];
        const dir = monthName + '_' + year;
        const day = date.getDate();
        fileName = (0, path_1.join)((0, path_1.dirname)(fileName), dir, day + '.log');
    }
    if (!fs_1.default.existsSync(fileName)) {
        const dir = (0, path_1.dirname)(fileName);
        fs_1.default.mkdirSync(dir, { recursive: true });
    }
    try {
        fs_1.default.appendFileSync(fileName, text);
    }
    catch (error) {
        console.error(coloredConsoleLog('LOGGING ERROR: ', 'scarlet', error.message));
    }
}
exports.logTextToFile = logTextToFile;
function getDateTime() {
    var currentDate = new Date();
    const date = currentDate.toLocaleDateString('en-US');
    const time = currentDate.toLocaleTimeString('en-US');
    return `${date} | ${time}`;
}
exports.getDateTime = getDateTime;
