import { dirname, join } from 'path';
import fs from 'fs';
import { colors } from "./colors.js";
export function getColoredText(text, color = 'black', ...notColoredTexts) {
    // const colors: { [key in Tcolor]: ChalkInstance } = {
    const coloredText = colors[color](text) + notColoredTexts;
    return coloredText;
}
export function coloredConsoleLog(text, color = 'black', ...notColoredTexts) {
    const coloredText = getColoredText(text, color);
    console.log(coloredText, ...notColoredTexts);
}
export const normalizeTexts = (...texts) => texts.map(text => {
    if (typeof text === 'object')
        return JSON.stringify(text);
    return text;
});
export function logTextToFile(text, fileName, separeteLogsByDate) {
    if (!fileName)
        return;
    if (separeteLogsByDate) {
        var months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
        const date = new Date();
        const year = date.getFullYear();
        const monthName = months[date.getMonth()];
        const dir = monthName + '_' + year;
        const day = date.getDate();
        fileName = join(dirname(fileName), dir, day + '.log');
    }
    if (!fs.existsSync(fileName)) {
        const dir = dirname(fileName);
        fs.mkdirSync(dir, { recursive: true });
    }
    try {
        fs.appendFileSync(fileName, text);
    }
    catch (error) {
        console.error(coloredConsoleLog('LOGGING ERROR: ', 'scarlet', error.message));
    }
}
export function getDateTime() {
    var currentDate = new Date();
    const date = currentDate.toLocaleDateString('en-US');
    const time = currentDate.toLocaleTimeString('en-US');
    return `${date} | ${time}`;
}
